***
API
***

Tracing
=======

.. py:module:: ddtrace

.. automodule:: ddtrace.auto

.. autofunction:: ddtrace.patch

.. autoclass:: ddtrace.trace.Tracer
    :members:

.. autoclass:: ddtrace.trace.Span
    :members:

.. autoclass:: ddtrace.trace.Pin
    :members:

.. autoclass:: ddtrace.trace.Context
    :members:
    :undoc-members:

.. autoclass:: ddtrace.propagation.http.HTTPPropagator
    :members:

.. automodule:: ddtrace.opentelemetry
    :members:


Runtime Metrics
===============

.. autoclass:: ddtrace.runtime.RuntimeMetrics
    :members:


Dynamic Instrumentation
=======================

.. automodule:: ddtrace.debugging
    :members:


Source Code Integration
=======================

.. automodule:: ddtrace.sourcecode
    :members:
